package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````,"````````!``````````#BA````
M`````````$``.``'`$``%@`5``8````$````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````("+````````@(L`````````
M``$```````$````&````:)L```````!HFP$``````&B;`0``````$`4`````
M``!P%0```````````0```````@````8```"`FP```````(";`0``````@)L!
M``````#@`0```````.`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````:)L```````!HFP$``````&B;`0``````F`0```````"8!`````````$`
M````````+VQI8B]L9"UM=7-L+6%A<F-H-C0N<V\N,0`````````1````4```
M``0````(````(0````7`!(`H`!`!@(9`@((A``0)``2)B(`80;H$`@A0````
M40```%4```!:````6P```&$```!B````8P````````!E``````````````!F
M````9P```&D```````````````&O-.AJ?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-
M\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`5COEWF[XY)\5<,\
MTF>OS&:(!W#30T75[#-BV^U_J9R;X*<""K_:5QNCX/M)````````````````
M```````````````````````````#``<`&!H````````````````````````#
M``\`>)L!``````````````````P````2`````````````````````````.<!
M```2`````````````````````````!0````1````````````````````````
M``T"```1`````````````````````````(D!```2````````````````````
M`````!L````2`````````````````````````,8!```2````````````````
M`````````",````2`````````````````````````"H````2````````````
M`````````````!H"```2`````````````````````````-(!```2````````
M`````````````````#,````@`````````````````````````&0#```A````
M`````````````````````$L````2`````````````````````````%$````2
M`````````````````````````%@````2`````````````````````````"H#
M```2`````````````````````````!L#```2````````````````````````
M`)\"```2`````````````````````````%\````2````````````````````
M`````$`"```2`````````````````````````&8````2````````````````
M`````````-0"```2`````````````````````````&T````2````````````
M`````````````'4````@`````````````````````````(D````2````````
M`````````````````+T"```2`````````````````````````)$````2````
M`````````````````````)<````2`````````````````````````*`````@
M`````````````````````````!0#```2`````````````````````````+P`
M```2`````````````````````````,$````2````````````````````````
M`"L"```1`````````````````````````-L"```2````````````````````
M`````&T"```2`````````````````````````#H#```2````````````````
M`````````%\"```2`````````````````````````,(#```2````````````
M`````````````.8"```1`````````````````````````&,#```1````````
M`````````````````)$"```2`````````````````````````%`#```2````
M`````````````````````&4#```1`````````````````````````,@````2
M`````````````````````````$@#```2`````````````````````````-$`
M```1`````````````````````````)<!```2````````````````````````
M`.,````B`````````````````````````/(````@````````````````````
M``````@!```2``````````````````````````P#```2````````````````
M`````````'T"```2``````````````````````````T!```2````````````
M`````````````!,!```@`````````````````````````,@"```2````````
M`````````````````"T!```2`````````````````````````+<!```2````
M`````````````````````#(!```2`````````````````````````*T"```2
M`````````````````````````*8!```2`````````````````````````#@!
M```2`````````````````````````$D!```2````````````````````````
M`#L"```2`````````````````````````)(````2````````````````````
M`````$P"```2`````````````````````````(8"```2````````````````
M`````````$$#```2`````````````````````````$\!```2````````````
M`````````````#(#```2`````````````````````````&,!```2````````
M`````````````````#8"```2`````````````````````````/4!```2````
M`````````````````````&H!```2`````````````````````````'$!```2
M`````````````````````````&(#```A`````````````````````````((!
M```2`````````````````````````(\#```0`!,`V+`!````````````````
M`%T#```2``D`,!X``````````@````````<"```2``H`4$P````````$````
M``````0$```2``D`O#\```````#D"````````'H$```2``D`Z$L```````!H
M`````````.$#```2``D`Z#D````````$`````````!,$```2``<`&!H`````
M```$`````````"<$```2``D`H$@```````!(`P```````(`#```0`!,`>*`!
M`````````````````&T$```2``D`[#D```````#0`0```````'0#```0`!,`
M>*`!`````````````````/(#```2``D`"#\```````"T`````````!$$```2
M``D`+#@````````X`````````!D$```2``D`A#X```````!<`````````$<$
M```2``D`O#L````````@`````````)H#```0`!,`V+`!````````````````
M`*(#```0`!,`V+`!`````````````````*<#```2``D`3"`````````P````
M`````%0$```2``D`W#L````````$`0```````#T$```1`!(`<*`!```````(
M`````````&T#```0`!(`>*`!`````````````````'D#```2``D`,"``````
M`````````````+`#```2``D`X#X````````H`````````,L#```2``D`N#@`
M```````P`0```````(X#```0`!,`V+`!`````````````````&`$```2``D`
MX#P```````"D`0````````!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E
M86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O
M`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*
M=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`
M7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F
M<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G
M971S<&5C:69I8P!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T
M=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ`&9P<FEN=&8`<W1R9'5P
M`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S=')C:'(`<W1R=&]K
M`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV:7)O;@!?961A=&$`
M7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?
M`%]E;F0`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A
M;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%``````!HFP$`````
M``,$````````4"$```````!PFP$```````,$````````Z"````````!PGP$`
M``````,$````````,!X```````"(GP$```````,$````````4$P```````"H
MGP$```````,$````````&!H`````````H`$```````,$`````````*`!````
M```0H`$```````,$````````0D\````````8H`$```````,$````````C4P`
M```````HH`$```````,$````````;DT````````PH`$```````,$````````
M9TT````````XH`$```````,$````````-D\```````!`H`$```````,$````
M````A$T```````!(H`$```````,$````````/D\```````!8H`$```````,$
M````````*$\```````!@H`$```````,$````````+4\```````!PH`$`````
M``,$````````1T\```````!XGP$```````$$```%``````````````"`GP$`
M``````$$```&``````````````"0GP$```````$$```.``````````````"8
MGP$```````$$```;``````````````"@GP$```````$$```@````````````
M``"PGP$```````$$```D``````````````"XGP$```````$$```J````````
M``````#`GP$```````$$```N``````````````#(GP$```````$$```Q````
M``````````#0GP$```````$$```S``````````````#8GP$```````$$```T
M``````````````#@GP$```````$$```Y``````````````#HGP$```````$$
M```^``````````````#PGP$```````$$```_``````````````#XGP$`````
M``$$``!$``````````````!XG0$```````($```#``````````````"`G0$`
M``````($```$``````````````"(G0$```````($```'``````````````"0
MG0$```````($```(``````````````"8G0$```````($```)````````````
M``"@G0$```````($```*``````````````"HG0$```````($```+````````
M``````"PG0$```````($```,``````````````"XG0$```````($```-````
M``````````#`G0$```````($```.``````````````#(G0$```````($```0
M``````````````#0G0$```````($```1``````````````#8G0$```````($
M```2``````````````#@G0$```````($```3``````````````#HG0$`````
M``($```4``````````````#PG0$```````($```5``````````````#XG0$`
M``````($```6````````````````G@$```````($```7```````````````(
MG@$```````($```8```````````````0G@$```````($```9````````````
M```8G@$```````($```:```````````````@G@$```````($```<````````
M```````HG@$```````($```=```````````````PG@$```````($```>````
M```````````XG@$```````($```?``````````````!`G@$```````($```A
M``````````````!(G@$```````($```B``````````````!0G@$```````($
M```C``````````````!8G@$```````($```E``````````````!@G@$`````
M``($```F``````````````!HG@$```````($```G``````````````!PG@$`
M``````($```H``````````````!XG@$```````($```I``````````````"`
MG@$```````($```L``````````````"(G@$```````($```M````````````
M``"0G@$```````($```O``````````````"8G@$```````($```P````````
M``````"@G@$```````($```R``````````````"HG@$```````($```S````
M``````````"PG@$```````($```T``````````````"XG@$```````($```U
M``````````````#`G@$```````($```V``````````````#(G@$```````($
M```W``````````````#0G@$```````($```X``````````````#8G@$`````
M``($```Z``````````````#@G@$```````($```[``````````````#HG@$`
M``````($```\``````````````#PG@$```````($```]``````````````#X
MG@$```````($``!`````````````````GP$```````($``!!````````````
M```(GP$```````($``!"```````````````0GP$```````($``!#````````
M```````8GP$```````($``!%```````````````@GP$```````($``!&````
M```````````HGP$```````($``!'```````````````PGP$```````($``!(
M```````````````XGP$```````($``!)``````````````!`GP$```````($
M``!*``````````````!(GP$```````($``!+``````````````!0GP$`````
M``($``!,``````````````!8GP$```````($``!-``````````````!@GP$`
M``````($``!/``````````````#]>[^I_0,`D?U[P:C``U_6``````````#P
M>[^IT```D!&Z1OD0PC61(`(?UA\@`]4?(`/5'R`#U=```)`1OD;Y$.(UD2`"
M'];0``"0$<)&^1`"-I$@`A_6T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6_7N[J?T#`)'S4P&I
MTP``T/43`/G4``"0H$\`N:!#`9&A(P#YH0,!D0*,'OCB`P"JH#,!D8___Y?"
M``"0P```D$+\1_D`^$?YX0,"JBW__Y?```"0`,!'^0``0#F``0`U8/__EV+"
M!I%``!+X8```M2``@%*+__^7HO__EX#:1_D``$"YO___EQ^$)#F4VD?Y@`)`
MN;O__Y<!Z%,Y(0`?,@'H$SF``D"YMO__EP'H4SDA```R`>@3.0$`_)*@3T"Y
M`!0`$0!\0),?``'KR0``5,$``)````#P`$PSD2'<1_GP_O^7`/!]TW[__Y>E
M(T#Y8L(&D>0`@))``!'XH0!`^0$``/D!``#P(8@\D0$$`/G!``"P(3A`^0$(
M`/D!``#P(90\D0$,`/F!`(!208`0N`$`@-*B3T"Y(00`D5\``6ML!0!401``
M$77"!I'C`P"J0@P`$8',(8L$`(#2'V@A^`$``-"@`E+X(9`AD07__Y?T`P`J
M@```-:`"4OA1__^7]`,`*G7"!I&@`E+X*?__EP```/``A#21]00`E&`!`+6@
M@E'XH```M0```/``6#.1[P0`E*""$?A@P@:1`(!1^$```+3]"@"4<\(&D6`"
M4OAX__^7F_[_E_430/G@`Q0J\U-!J?U[Q:C``U_6(Q``$:9X8?B#S".+!F@C
M^,___Q<=`(#2'@"`TN`#`)&A``#P(0`ND1_L?)(!```4_7N_J:0``/"C``#P
M`B``D?T#`)$!`$"YH```\(3$1_D%`(#28]1'^0"X1_G^_O^7P0``D,```)`A
MX`&1`.`!D2$<`)$A``#+/S@`\:D``%2A``#P(=!'^4$``+0@`!_6P`-?UL``
M`)#!``"0`.`!D2'@`9$A``#+0@"`TB'\0Y,A#,*:H0``M*(``/!"\$?Y0@``
MM$``'];``U_6P```D`'@03GA`@`U_7N^J?T#`)'S"P#Y\P,`JJ```/``Z$?Y
M@```M,```)```$#YYO[_E]C__Y>@``#P`,A'^8```+0@``#0`/`MD6O^_Y<@
M`(!28.(!.?,+0/G]>\*HP`-?UL`#7]:@``#P_7N_J?T#`)$`[$?YP```M,$`
M`)`@``#0(0`"D0#P+9'3_O^7H```\`#@+9$!`$#YH0``M*$``/`AS$?Y00``
MM"``/];]>\&HQ?__%_]#"M&G``#P".``D0,`@-+]>[^I_0,`D>'D1_DB`$#Y
MHD\!^0(`@-*A8P"1)B``D05I8_@":6.X8R``D7\``?%"",!:PH`?^*+\8--$
M'&C30MQXTT(<<)*"``*JI/QHTX0<>)*%X$6J0@`%JL($`?@!_O]4)``(D2,@
M0/DA(`"1(C!`^26`7_A"``/*(P1`^6,`!<I"``/*0_Q?TV($`JI"?$"2(CP`
M^9\``>MA_O]4"2!`J0HL0:D``6>>80%GG@7]0M-"`6>>(OU;TZ5X"*JC#T#Y
ML'Q`DD(4":H,$$#Y+_U"T^]Y":I`'&$N`0)GGN]]0)(!`&:>(`%GGB`<8BXB
M0"*+(3./TD%0J_)C``&+0@`#BZ,30/D$`&:>0@`,BTY\0))C``&+0@`/BH0`
M"XN#``.+Q/U;TX04#JID0"2+`P(NBF,``JJB%T#YAGQ`DF,`"HM"``&+Y0$F
MBF,``HO"_4+3S?Q;TT)X#JI"?$"2K14&JHX``HK$_$+3;4`MBZ4`#JJ&>`:J
MHWU`DL9\0))$`".*K0$&BJ4`$(N$``VJ</Q;TX0`#XNN/T.I$!8#JLX!`8OO
M`0&+I0`.BV[\0M.$``^+L$`PB\-Y`ZH%?D"28WQ`DLX`)8H0`@.*S@$0JJW\
M6]/"`0*+KB-`^:T5!:K.`0&+C4`MBT(`#HND?4"2KOQ"TV\`)(K%>06JD/Q;
MTX[\0M.E?$"2$!8$JL1Y!*J$?$"2K0$%BE!`,(OO`0VJ`GY`DA`"!(JN`"**
MY@$&B\X!$*K#`0.+3?Q;TZ^[1*FM%0*J[P$!B\X!`8O&``^+8P`.BT[\0M/-
M0"V+IGU`DL)Y`JJ/`":*0GQ`DJT!`HK0_%O3SOQ"T^\!#:H0%@:JQGD&JL9\
M0)+E`06+<$`PBP-^0)(0`@:*3@`CBLX!$*K$`02+;?Q;TZ^[1:FM%0.J[P$!
MB\X!`8NE``^+A``.BV[\0M.M0"V+I7U`DL-Y`ZK/`"6*8WQ`DJT!`XJP_%O3
MKOQ"T^\!#:H0%@6JQ7D%JJ5\0)+B`0*+D$`PBP1^0)(0`@6*;@`DBLX!$*K&
M`0:+C?Q;TZ^[1JFM%02J[P$!B\X!`8M"``^+Q@`.BX[\0M--0"V+HGU`DL1Y
M!*JO`"**A'Q`DJT!!(I0_%O33OQ"T^\!#:H0%@*JPGD"JD)\0)+C`0.+T$`P
MBP9^0)(0`@**C@`FBLX!$*K%`06+S?Q;TZ^[1ZFM%0:J[P$!B\X!`8MC``^+
MI0`.B\[\0M-M0"V+HWU`DL9Y!JK&?$"23P`CBJT!!HIP_%O3[P$-JN0!!(L0
M%@.JK[=(J;!`,(L%?D"2[P$!BZT!`8NN_%O3A``/B\X5!:J10"Z+9/Q"TS)^
M0)+.`"6*@W@#JF-\0)(0`@.*;P`RBLX!$*I0_EO3P@$"BT(`#8L0%A*J4$`P
MBZ+\0M,$?D"217@%JJ5\0)(N`@6*K0`DBN\!#JJ._%O3[P$&BZ9/0/G.%02J
MQ@`!B^\!!HM&_D+3[T$NBX[\0M/&>!*JXGU`DL1Y!*K&?$"2A'Q`DA`"!HK.
M`"**[P$$BJT!$*K.`0^JHP$#B\4!!8NM.TJIK0$!B\X!`8MC``V+3?Q;TZ4`
M#HNM%0*J;4`MBZ-]0))N_%O3SA4#JJ5`+HM._$+3L'Q`DL)Y`JJ.`".*3WQ`
MDJT!#XK-`0VJK0$&BZ9;0/G!``&+!OY;TZ$!`8O&%!"J,D`FBV'\0M--?D"2
M(W@#JB%TG=)"``/*(=NM\D(`!4JE_5O30@`$BZ1?0/FE%`VJA``!BT(`!(L$
M_D+3A'@0JD)`)8MF``3*I6-`^5%\0)+&`!)*I0`!B\8`#XO&``6+I?U"TR[^
M6].M>`VJSA41JH4`#<JE``)*(OY"T\9`+HO0?$"2I4`CBZ-G0/E">!&J8P`!
MBZ4``XL#_EO38Q00JJ-`(XNE`0+*;WQ`DJ8`!DJE:T#YQ$`DBP;^0M/N_5O3
MI0`!BX0`!8O&>!"JSA4/JD4`!LJC``-*I6]`^81`+HN1?$"2I0`!BV-`+8MC
M``6+Y?U"TRW^6].E>`^JK141JF-`+8O-``7*I`$$2G!\0)*"0"*+I'-`^0W^
M6].$``&+0@`$BR3^0M.M%1"JA'@1JD)`+8NM``3*HP$#2DY\0))F0":+HW=`
M^<W]6]-C``&+Q@`#BP/^0M.M%0ZJ8W@0JL9`+8N-``/*H@$"2M%\0))%0"6+
MHGM`^2W^6]-"``&+I0`"B\+]0M.M%1&J0G@.JJ5`+8MM``+*I@$&2J]\0)+$
M0"2+IG]`^>W]6]/&``&+A``&BR;^0M.M%0^JQG@1JH1`+8M-``;*I0$%2HY\
M0)*C0".+I8-`^<W]6].E``&+8P`%B^7]0M.M%0ZJI7@/JF-`+8O-``7*I`$$
M2G!\0)*"0"*+I(=`^0W^6].$``&+0@`$B\3]0M.M%1"JA'@.JD)`+8NM``3*
MHP$#2D]\0))F0":+HXM`^>W]6]-C``&+Q@`#BP/^0M.M%0^J8W@0JL9`+8N-
M``/*H@$"2LY\0))%0"6+HH]`^<W]6]-"``&+I0`"B^+]0M.M%0ZJ0G@/JJ5`
M+8MM``+*I@$&2K%\0)+$0"2+II-`^2W^6]/&``&+A``&B\;]0M.M%1&JQG@.
MJH1`+8M-``;*I0$%2I!\0)*C0".+I9=`^0W^6].E``&+8P`%BR7^0M.M%1"J
MI7@1JF-`+8O-``7*I`$$2F]\0)*"0"*+I)M`^>[]6].$``&+0@`$BP3^0M/.
M%0^JA'@0JJT`!,I.0"Z+PGU`DJ,!`TIF0":+HY]`^4W\6]-C``&+Q@`#BZT5
M`JKC_4+3S4`MBV]X#ZJF?4"2@P`/RFX`#DJCHT#YQ4$EB\[\6]-C``&+I0`#
MB\X5!JI#_$+3KD`NBV)X`JK%?4"2XP$"RFT`#4JCIT#YI$$DBZW\6]-C``&+
MA``#BZT5!:K#_$+3C4`MBV9X!JJD?4"20P`&RF,`#DJNJT#YP0$!BX[\6]-C
M0"^+80`!B\X5!*HQ0"Z+H?Q"TR-^0)(E>`6JSP`%JL$`!8KM`0V*K0$!*H&;
ME])AX['RHD$BBZVO0/FM`0&+0@`-BVW\6].M%0.J4$`MBXW\0M,"?D"2I'D$
MJJX`!*JM``2*S@$1BLX!#2IM_$+3QD$FBZZS0/FC>0.JS@$!BXT``ZK&``Z+
M3OQ;TZT!$(K.%0*JST`NBXX``XJM`0XJYGU`DJ5!)8NMMT#YK0$!BZ4`#8O-
M_%O3K14&JK!`+8M-_$+3!7Y`DJ)Y`JIN``*J;0`"BLX!#XK.`0TJS?Q"T\1!
M)(NNNT#YIGD&JLX!`8M-``:JA``.BZ[\6].M`1"*SA4%JH]`+HM.``:*K0$.
M*N1]0)*C02.+K;]`^:T!`8MC``V+C?Q;TZT5!*IP0"V+K?Q"TP-^0)*E>06J
MS@`%JLT`!8K.`0^*S@$-*HW\0M/"02*+KL-`^:1Y!*K.`0&+K0`$JD(`#HMN
M_%O3K0$0BLX5`ZI/0"Z+K@`$BJT!#BKB?4"2ID$FBZW'0/FM`0&+Q@`-BTW\
M6].M%0*JT$`MBVW\0M,&?D"2HWD#JHX``ZJ-``.*S@$/BLX!#2I-_$+3Q4$E
MBZ[+0/FB>0*JS@$!BVT``JJE``Z+SOQ;TZT!$(K.%0:JKT`NBVX``HJM`0XJ
MY7U`DJ1!)(NMST#YK0$!BX0`#8NM_%O3K14%JI!`+8O-_$+3!'Y`DJ9Y!JI.
M``:J30`&BLX!#XK.`0TJK?Q"T\-!(XNNTT#YI7D%JLX!`8O-``6J8P`.BX[\
M6].M`1"*SA4$JF]`+HO.``6*K0$.*N-]0)*B02*+K==`^:T!`8M"``V+;?Q;
MTZT5`ZI00"V+C?Q"TP)^0)*D>02JK@`$JJT`!(K.`0^*S@$-*FW\0M/&02:+
MKMM`^:-Y`ZK.`0&+C0`#JL8`#HM._%O3K0$0BLX5`JK/0"Z+C@`#BJT!#BKF
M?4"2I4$EBZW?0/FM`0&+I0`-B\W\6].M%0:JL$`MBTW\0M,%?D"2HGD"JFX`
M`JIM``**S@$/BLX!#2K-_$+3Q$$DBZ[C0/FF>0:JS@$!BTT`!JJ$``Z+KOQ;
MTZT!$(K.%06JCT`NBTX`!HJM`0XJY'U`DJ-!(XNMYT#YK0$!BV,`#8N-_%O3
MK14$JG!`+8NM_$+3`WY`DJ5Y!:K.``6JS0`%BLX!#XK.`0TJC?Q"T\)!(HNN
MZT#YI'D$JLX!`8NM``2J0@`.BV[\6].M`1"*SA4#JD]`+HNN``2*K0$.*N)]
M0)*F02:+K>]`^:T!`8O&``V+3?Q;TZT5`JK00"V+;?Q"TP9^0)*C>0.JC@`#
MJHT``XK.`0^*S@$-*L5!)8NN\T#YS@$!BZ4`#HO._%O3SA4&JJY`+HM%_$+3
MSWU`DJ)X`JIM``*J90`"BJT!$(JM`04JQ?Q"TZ9X!JJD022+10`&JJ4`#HI.
M``:*I0`.*J-`(XNMEUZIY^1'^:T!`8NA``&+A``-B^W]6]-C``&+K14/JHU`
M+8ND?4"2COQ;T\X5!*IN0"Z+X_U"T\5]0))O>`^JH_]`^<$`#\HA``U*K?Q;
MTR)`(HO!.IC204RY\JT5!:IC``&+0@`#BX/\0M-D>`2J0D`MB^,!!,I1?$"2
M8P`.2F9`)HNC`T'Y+OY;TV,``8O&``.+SA41JJ/\0M/.0"Z+)OY"T]!]0))E
M>`6J@P`%RM%X$:IC``)*H@=!^0W^6].F`!'*0@`!BV-`+XNM%1"J8P`"B\8`
M#DH"_D+38T`MBV]\0)+$0"2+I@M!^4)X$*KM_5O3Q@`!BX0`!HLF`@+*K14/
MJL,``TJ$0"V+94`EBY)\0)*C#T'Y8P`!BTW^6].E``.+X_U"TZT5$JIC>`^J
MI4`MBT8``\JP?$"2Q@`$2J030?G&0#&+A``!BPW^6]/&``2+1/Y"TZT5$*J$
M>!*JQD`MBVT`!,JE`05*SGQ`DJ)`(HNE%T'YS?U;TZ4``8M"``6+!?Y"TZT5
M#JJE>!"J0D`MBXT`!<JF`09*47Q`DL-`(XNF&T'Y+?Y;T\8``8MC``:+QOU"
MTZT5$:K&>`ZJ8T`MBZT`!LJB`0)*;WQ`DD1`)(NB'T'Y[?U;TT(``8N$``*+
M(OY"TZT5#ZI">!&JA$`MB\T``LJC`0-*CGQ`DF5`)8NC(T'YS?U;TV,``8NE
M``.+X_U"TZT5#JIC>`^JI4`MBTT``\JD`01*L'Q`DH9`)HND)T'Y#?Y;TX0`
M`8O&``2+Q/U"TZT5$*J$>`ZJ;@`$RL9`+8O%`05*S7Q`DJ)`(HNE*T'YKOU;
MTZ4``8M"``6+!?Y"T\X5#:JE>!"JCP`%RD)`+HOF`09*3GQ`DL-`(XNF+T'Y
MQ@`!BV,`!HO&_5O3QA0.JF-`)HNF_4+3;WQ`DLUX#:JF``W*P@`"2N;]6]-$
M0"2+HC-!^<84#ZI"``&+A``"B\+]0M-">`ZJA$`FBZX!`LJ&?$"2PP$#2F5`
M)8NC-T'YSOQ;TV,``8NE``.+X_U"T\X5!JIC>`^JI4`NBTX``\JP?$"2Q`$$
M2HU`+8ND.T'Y#_Y;TX0``8NM`02+[Q40JL3\0M.O02^+[7U`DH9X!JID``;*
MA0`%2J0_0?FN_5O3A``!BZ)`(HM"``2+SA4-J@7^0M-.0"Z+L'@0JL)]0)+$
M`!#*I4-!^8\`#TJD_4+3I0`!B^-!(XM/_%O38P`%BXUX#:KO%0*JK`$,"PP0
M`/EE0"^+#P(-RNX!#DJC?$"2Q$$FBZ9'0?G&``&+A@`&BV3\6].$%`.JA``&
M"T;\0M,(`00+PG@"JF;\0M-+``L+PW@#JJ8!`LK%``5*IDM!^6H`"@O!``&+
MI4`PBZ4``8N!_%O3"BP!J2$4!*HA``4+*0`)"PD@`*FA3T'YX`!`^2```,I`
M``"TT/K_E_U[P:C_0PJ1P`-?UOU[O*G]`P"1\U,!J10`@-+U6P*I]V,#J>``
M`+2B``#0%`"`TD+@1_E7`$#YX@,`JA<!`+7@`Q2J\U-!J?5;0JGW8T.I_7O$
MJ,`#7]9"!`"10P!`.7_T`'%D&$!Z@?__5$(``$OX`P&J]@,`JO4#%ZI3?$"3
MM`)`^?3]_[3B`Q.JX0,6JN`#%*H.^O^70`$`-8!J<S@?]`!QX0``5+4"%\MS
M!@"1E`(3B[7^0Y,5`P"YX?__%[4B`)'O__\7_7N]J?T#`)'S"P#YLP``T'/F
M1_EA`D#YH1<`^0$`@-*ADP"1R/__EZ(70/EA`D#Y00`!RD$``+2/^O^7\PM`
M^?U[PZC``U_6_7N\J?T#`)'U6P*I]0,`JJ```-#S4P&IM```T/,#`*JVTP"1
M`>1'^93B1_DB`$#YHA\`^0(`@-+A`Q:JX`,5JJ___Y?@``"U8.9'^:$?0/D`
M`$#Y(```RD`!`+1T^O^7H#>`N8$"0/D@#`"+`01`^0$``/DA_O^T`"``D?S_
M_Q?S4T&I]5M"J?U[Q*C``U_6_7NZJ?T#`)'S4P&IM```T/5;`JGU`P&J]V,#
MJ?8#`*KY:P2I@.9'^0$`0/FA+P#Y`0"`TJ`"0#D?]`!QM1:5FN`#%:I2^O^7
M]P,`JJ%3`9'@`Q:JAO__ER`"`+3S`P"J2_K_E_\"`.MH!@!4``"`TJ%J8#AA
M:B`X``0`D:'__S4``(!2E.9'^:(O0/F!`D#Y00`!RL$)`+1!^O^7LP``T&#B
M1_D9`$#Y``"`TO@#`"H`!`"1(0\`BR&`7_B!__^UH0``\``+`!$BL$"Y(@$`
M-`%\?9/@`QFJ3?G_EV'B1_D@``#YP`$`M0``@!+F__\7`'Q]DR(`@%(BL`"Y
MA/G_E_H#`*H@__^T`G]]D^$#&:J#^?^78.)'^1H``/ESXD?Y`']`DP`$`)%A
M`D#Y/W@@^+A7`+GA`Q:J(`!`.1_T`'$$&$!Z`00`5+,``-"X5X"Y(0`6R^`*
M`)%SXD?Y`,`ABQCS?=-Y`D#Y:?G_ER!K./C`^_^T8`)`^:%7@+D#>&'X``"`
MTL%J8#AB``"+/_0`<6%H(#@D&$!Z``0`D4'__U2@!X!20```.0``@-)#``"+
MH6I@.``$`)%A!``Y@?__-;#__Q<A!`"1W/__%_-30:GU6T*I]V-#J?EK1*G]
M>\:HP`-?UOU[LJG]`P"1\U,!J;0``-#U6P*I]V,#J?EK!*F!YD?Y(@!`^:)O
M`/D"`(#28`(`M`$`0#GU`P"J`0(`-._X_Y?W`P"JH`$`M!@``+`9``"P&#<R
MD3DS,I&Z8P&1X`,7JAKY_Y=@`0"UX`,7JD/Y_Y?@`Q6JG?G_EY3F1_FA;T#Y
M@`)`^2```,I@!0"TR_G_EQ-,`)'A`QBJX`,3J@?Y_Y?@_?\TX0,9JN`#$ZH#
M^?^78/W_-.`#%:J\^?^7]@,`JN`#$ZJY^?^7```6"P`(`!$`?$"3%?G_E_8#
M`*H!``"PXP,3JN(#%:HA/#*1G_G_E^$#&JK@`Q:JC/G_EQ\$`#%``0!4H&M`
MN0`,%!(?$$!QP0``5.`#%JJZ__^7X`,6JG[Y_Y?.__\7X`,6JOOX_Y?[__\7
M\U-!J?5;0JGW8T.I^6M$J?U[SJC``U_6_7NUJ?T#`)'S4P&ILP``T/0#`*IA
MYD?Y(@!`^:)7`/D"`(#2H:,`D?WX_Y=``@`UH3M`N0(`E%(A#!02/Q!`<200
M0GK!``!4X`,4JD$`@%*K^/^7'P``<>`7GQISYD?YHE=`^6$"0/E!``'*@0``
MM'_Y_Y<``(!2^?__%_-30:G]>\NHP`-?UJ```-#]>[^I_0,`D0#81_D``$"Y
M7/G_EZ(``-`#``"P`0``L&.`,9']>\&H(50RD4+T1_E,^?\7_7N^J?T#`)'S
M"P#YLP``T'/:1_E@`D"Y3?G_E^O__Y=@`D"Y2OG_E_,+0/D$``"P`@``L(2$
M/)$!``"P_7O"J.,#!*I"@"*1(<0RD04`@%*#^/\7_PM`T?^#`-']>[VI_0,`
MD?5;`JFV``#0\U,!J;3C`)'`YD?Y`0!`^:$G$/D!`(#2AOC_E^,#`"H$``"P
M`@``L(08,Y%"*#.1X`,4JB$`@M)J^/^7'P0`,2$!`%0#`(#2P>9'^>`#`ZJB
M)U#Y(0!`^4$``<HA!0"T./G_EP%\0),_!$#Q20``5`!](-2`_O\W``B"T@(`
M@M*S`P"+X`,4JN$#$ZK)^/^7]0,`JH#]_S<`!``1`'Q`DX3X_Y?C`P"JX/S_
MM!\`$^NT?D"3@@``5```%(M_`@#K@_W_5'\`$^N)``!48`(4BW\``.OC_/]4
M(`""4K\"`&N,_/]4X`,#JN(#%*KA`Q.J!/G_E^,#`*H?:#0XT___%_-30:GU
M6T*I_7O#J/\+0)'_@P"1P`-?UK3__Q?_!T#1_T,"T?U[NJG]`P"1\U,!J;0`
M`-#U6P*I]0,`JOEK!*GS`P&J]V,#J8#F1_G[*P#Y`0!`^:%W"/D!`(#2````
ML`!8,Y%:_O^7^@,`JN`#%:KA!8!2>_C_EX`!`+0```"PX0,5J@!\,Y&'_O^7
ME.9'^>`#%:JB=TCY@0)`^4$``<I!"0"TY_C_E^`#%:H6``"P%P``L!D``+#W
M-C*1.;LSD=SX_Y?X`P`JP;(SD>`#$ZH8!P`1O_C_E_,#`*H3_?^T8`)`.1\`
M`''S`I.:6@$`M.$#$ZK@`QJJ$OC_E\```#7!LC.1``"`TK+X_Y?S`P"J\___
M%^`#$ZK&^/^78<(@BR'P7S@_O`!Q(`(`5``#``L?_#]Q3/K_5+NC`Y$"``"P
MY0,5JN0#&:KC`Q.J0B@WD>`#&ZH!`(+2XO?_EP`$`!$?!$!QJ0``5`!](-0`
M!`!1?\H@..K__Q>AHP&1X`,;JHSX_Y?@^_\UH'M`N0`,%!(?($!Q8?O_5.`#
M&ZHA`(!2S/?_E^#Z_S4```"PX0,;J@!\,Y$\_O^7X`,;JA7X_Y?U`P"JLO__
M%_-30:GU6T*I]V-#J?EK1*G[*T#Y_7O&J/\'0)'_0P*1P`-?U@$$`)$B\%\X
M0@``-<`#7]9?O`!Q`!"!FB$$`)'Z__\7P`<`M/U[OJG]`P"1\U,!J?,#`*H4
M`$`YU```-0```+``-#*1\U-!J?U[PJCV]_\7??C_EP($`-%B`@*+?P("ZZ("
M`%1``$`Y'[P`<:`!`%1``$`Y'[P`<8$!`%1"!`#1?P("ZV,"`%1"`!/+0`@`
MD1\$0/%I`@!4``"`TAP``!1"!`#1[O__%T($`-%_`@+K`_[_5'\"`NLA_O]4
MG[X`<>#[_U0```"P`+@SD=[__Q=``$`Y'[P`<2#]_U3K__\70@0`D5\$0/%)
M``!4`'T@U+0``/#A`Q.JE,("D90B`)'@`Q2J]/?_E^`#%*KS4T&I_7O"J,`#
M7]8```"P`#0RD<O__Q?]>[FI_0,`D?-3`:FS``#0]5L"J18``+#W&P#Y%P``
ML&#F1_D4``"P%0``L`$`0/FA-P#Y`0"`T@```+``@#&1M=XTD0`H`)$"#$"I
MH@\$J0(,0:D`0$!YH@\%J:##`'D```"P`,`SD:?]_Y<```"P`.0SD:3]_Y<`
M``"P``0TD:']_Y<```"P`"@TD9[]_Y?`1C21G/W_EP```+``A#21F?W_E^!:
M,Y&7_?^7@+8TD97]_Y?@`Q6JD_W_EP```+``!#61D/W_EP```+``?#.1C?W_
MEP```+``+#61>/W_EX```+3A`P"JX`,5JJK]_Y<```"P`'`UD7']_Y>@``"T
MX0,`J@```+``N#61HOW_EP```+``Y#61:?W_E\`!`+3A`P"JX%HSD9O]_Y<!
M``"PP$8TD2&4-I&7_?^7<^9'^:$W0/E@`D#Y(```RB`"`+3X]_^7````L``D
M-I%8_?^7X0,`JB`!`+4!``"PH$<!D2%H-I%"`8#2M0,!D5'W_Y=@_?\UH6X`
MD8"V-)'G__\7\U-!J?5;0JGW&T#Y_7O'J,`#7];]>[ZI_0,`D?,+`/FS``#P
M8`I`N1\$`#&A`0!4````L`"T-)$]_?^7`0"`4N```+0``$`Y'P``<>$'GQH?
MP`!QX`>?&B$```IA"@"Y8`I`N?,+0/G]>\*HP`-?UOU[OZG]`P"1SO?_EUGW
M_Y?A`P"J``"`TD$``+0@`$#Y_7O!J,`#7];]>[VI_0,`D?5;`JD5``"PMIXV
MD?-3`:GS`P"JX`,6JAW]_Y>```"T`0!`.?0#`*KA```UX0,3JJ">-I'S4T&I
M]5M"J?U[PZA)_?\7X0,3JBKW_Y>``@"UX`,3JJ?W_Y?U`P"JX`,4JJ3W_Y>@
M`@"+``@`D0'W_Y?U`P"J`P``L`$``+`A*#>1Y`,4JF.P,Y'B`Q.JB??_E^$#
M%:K@`Q:JY___%_-30:GU6T*I_7O#J,`#7];_(T#1`C60TO]#!=']>[JI_0,`
MD?EK!*FZ``#0]5L"J?8#`*KS4P&IH0,"B_=C`ZFW`P*1^W,%J;7#`I%`YT?Y
MM&,"D1L``)`"`$#Y(@``^0(`@-*@``#0`"``D0$@`)$B#$"IX@X`J0(,0JFB
M#@"I`@Q#J:(.`:D"#$2I`0Q`^:(.`JD"#$6IX0H`^0`P0/F"#@"I@`H`^6!;
M,Y'1_/^7NS\`^2`"`+0!`$`Y\P,`JL$!`#2F__^7X`,3JMKV_Y?T`P"J6N='
M^0$UD-*A`P&+X`,4JB(`0/E!`T#Y00`!R@$_`+1<]_^7C___E_,#`*H``@"U
M&`"`T@!K=/B```"U$P``D'/>-I$*```4M?S_EQ,`@-*@``"T`0!`.6$``#3!
M]O^7\P,`JA@C`)%S_O^TX`,3JAD``)`Y^S:10O?_EP#X?],`!`"1G_;_E_@#
M`*KT`P"J8@)`.0((`#43`(#2=&IU^)0!`+3@`Q2JG?S_E_0#`*K@!P"T`0!`
M.:$'`#2:_?^78`<`-.`#%*JF]O^7]`,`JA4`@-*T``"ULVIW^',``+1@`D`Y
M@`8`->`#%*H5``"0)/?_E_,#`*K@`QBJ(??_EQ,`$PMS$A`1<WY`D^`#$ZI\
M]O^7]P,`J@0``)`!``"0Y0,8JH0,-Y&CNC.1X@,4JB$@-Y$#]_^7X`,7J@$X
M@%+H]O^7'P0`,6$$`%3A]O^7``!`N1]$`''@`P!4H```L-0"0/D`O$?Y$P!`
M^=GV_Y<!``"0!`!`N>,#%ZKB`Q2J(40WD>`#$ZJV]O^7%`"`TIS__Q?@`Q2J
MX0,9JG,&`)&4"@"1Y_;_E[K__Q=S(@"1N___%^`#$ZI;_?^7@```-.`#$ZIG
M]O^7]`,`JK4B`)'!__\7N(,#D>`#%ZKA`QBJ6/;_E_P#`"J`+P`UH/-`N0`,
M%!(?$$!Q`2\`5+3[0+GH]O^7GP(`:X$N`%2@\T"Y`"``$A\`!W$!+@!4X`,3
MJCCV_Y?T`P"J````D`#(-I$[_/^7``$`M-,"0/E)]O^7X0,`JN`#$ZK)_?^7
M\P,`JD```+73`D#YX`,3JLGV_Y<?#`!Q^0,`JHT#`%0`?$"3`0``D``0`-$A
M,#B18`(`BP3V_Y>@`@`U/Q,`<<```%0Y$P!1><(YBR#S7S@?O`!QP0$`5-8&
M0/F6`0"TX`,6JK3V_Y<?#`#Q"0$`5``0`-$!``"0(40XD<`"`(OQ]?^7'P``
M<7,2EIK+_O^7`",`->`#$ZH!`(!2(O;_E_D#`"I@(@`T0@"`4B$"@)*VHP:1
MW/7_E^$#%JK@`QDJP@"`TF3V_Y>@HT8Y0`4`-:"G1CD?#`%QX00`5*"K1CD?
M!`%Q@00`5*"O1CD?#`%Q(00`5*"S1CD?(`%QP0,`5*"W1CD?%`%Q80,`5.`#
M&2I"`(!2(0>`DL/U_Y?A`Q:JX`,9*B(%@-)+]O^7!0``D.0#%JJEA#R1`0``
MD*.Z,Y'B`Q>J(5@XD>`#%*IJ]O^7X`,7JE3V_Y>@/T#YX0,4J@!8,Y$1_/^7
MX`,4JK3^_Y<1__\7X`,9*@(`@%(!`(#2'.,`D:CU_Y>__Q"I(&"$TK];`;F@
MZ*SRH',`^2!QE=*@^;WRH'<`^<"?F])`%[/RH'L`^<".BM)`!J+RH'\`^0`^
MG-)`>KCRH(,`^0#C`9&@.P#YX0,6JN`#&2H"`)#2'?;_EQ\``''E`P"J\P,`
M*FP,`%3@`QDJ#_;_E[/;4*FA8P21XP^`$F`B0],"!``1`'Q`DU_@`'$C:"`X
M0'Q`DZT5`%0!"(!2&>,`D2(``DL@`P"+`0"`4D)\0).2]?^7X`,8JB3W_Y?@
M`QFJ`@>`T@$`@%*,]?^7MD\%.<#^6-.S7P4YN8,%D:!#!3G`_E#3H$<%.<#^
M2-,6``"0H$L%.6#^6-/6^C:1H%,%.6#^4-.@5P4Y8/Y(TQ,`@-*@6P4YX`,8
MJKCC!9$+]_^7H'-`^:"/!3D!_%C3H8,%.0'\4-.AAP4Y`?Q(TZ!W0/FABP4Y
MH)\%.0'\6-.ADP4Y`?Q0TZ&7!3D!_$C3H'M`^:&;!3F@KP4Y`?Q8TZ&C!3D!
M_%#3H:<%.0'\2-.@?T#YH:L%.:"_!3D!_%C3H;,%.0'\4-.AMP4Y`?Q(TZ"#
M0/FANP4YH,\%.0'\6-.APP4Y`?Q0TZ''!3D!_$C3H<L%.6)J>3@`!Q.+X0,6
MJG,&`)'F]?^7?U(`\4'__U0%``"0OX,&.:6$/)'D`QBJ</__%Z&'0/F@?$"3
M(@P`"S\``NN)``!4H8M`^2$$`)&ABP#YH8M`^2!T0(NB@Q"IH%M!N6`$`#03
M"(!2<P(`2X##((N_`!-KL]"3&A\`%NM[?D"3@@``5`$`&XO?`@'KPP``5!\`
M%NNI``!4P0(;BQ\``>M"``!4`'T@U'\C0/&E-P#YJ/__5.(#&ZKA`Q:JO_7_
MEZ!;0;FE-T#Y8`(`"Q\``7&@6P&YH>W_5+,`$TO;`AN+X`,8JJGV_Y<"```4
M^P,6JG_^`'%L`@!4?P,<ZV)^0).)``!4@`,"BW\#`.O#_/]4?P,<ZX(``%1@
M`P*+GP,`ZR/\_U1?(`'QZ/O_5.$#&ZK@`QRJH?7_E[-;`;E3__\7H#M`^9\#
M&^L`,%OZR/K_5'\#'.MC`P&18@``5)\#`^LC^O]4X0,;JN`#'*H""(#2HS<`
M^7,"`5&0]?^7HS=`^?L#`ZK7__\7`0>`4@/C`)$B``)+8```BP$`@%)"?$"3
M6O__%P$``)````"0(90VD0"T-)$3``"0M;HSD7.&/)$6``"0)OO_E];..)''
M]/^7Y`,`*@$``)#E`Q.JXP,5JN(#%ZHAE#B1X`,4JF_U_Y?@`Q2J`3B`4E3U
M_Y<?!``Q(>#_5$WU_Y<``$"Y'T0`<:'?_U2U]/^7G`<`$>0#`"KF`Q.JY0,<
M*N,#%:KB`Q>JX0,6JN`#%*I<]?^7[?__%Z```+`!``"0P@)`^>,#%ZHA$#F1
M`+Q'^0``0/D;]?^79?[_%_-30:GU6T*I]V-#J?EK1*G[<T6I_7O&J/\C0)'_
M0P61P`-?UOU[NJG]`P"1\U,!J;,``+#U6P*I]V,#J73:1_GY:P2I^W,%J8`"
M0+DZ]?^7]0,`JH`"0+DW]?^7`.!".:#F`CD```"0`$0TD:WZ_Y?```"T`0!`
M.3_$`'%A``!4``1`.4```#3W_/^7==I'^;0``/"@`D"Y)_7_EP$``)!C`8!2
M(5PZD2(`@%*^]/^7(`0`M7;:1_G``D"Y'O7_EP$``)!C`(!2(7`ZD2(`@%*U
M]/^7]0,`JN`)`+5VVD?YP`)`N13U_Y<!``"08P"`4B&,.I$B`(!2J_3_E_4#
M`*H@#`"T````D`!\,Y&%^O^7]P,`JB`*`+3``D"Y!O7_EZ$*0/GB`Q>J(0!`
M^:;T_Y=5```4``A`^1N`@%*:P@:1%@"`4AL$H'(9%$#Y0(-0N-<&`!'_`@!K
M*@$`5*`"0+GU]/^7PGY`D^$#&:H#`(!25?3_E_@#`*I``@"U@,(&D0&`4+@A
M!`!1WP(!:T'Y_U1WVD?Y]0,`JC8`@%*@@E"XWP(`:XKX_U3@`D"YU@8`$>'T
M_Y?A`QFJ"_3_E_C__Q<!`$#Y0`-1^!S8=_@@#$"Y```;"A\`$'$!`0!4(`A`
M^>$#`*K@`QRJ*_3_EX#\_S7V`Q<JUO__%Z`"0+G.]/^7`0-`^4,`@%("`(#2
MVO3_E_3__Q?``D"YQ_3_EZ$*0/D"``"00G@ZD2$`0/EF]/^7H`I`^0``0/D`
M#$"Y`/6W-L`"0+F\]/^7H0I`^2$`0/DE]/^7HO__%WG[_Y?W`P"JP`)`N?<$
M`+2S]/^7H0I`^>(#%ZHA`$#Y4_3_E^`#%ZJ=]/^7<]I'^6`"0+FJ]/^7]0,`
MJF`"0+FG]/^7`0``D"(`@%(AE#J1V_/_E^$#`*H"``"0X`,5JD+H.I%"]/^7
M8`)`N9/"!I&;]/^7'^0".0```)``6#.1$OK_EV""$?C``0"U8`)1^!;]_Y=@
M@A'X0`$`M0```)```#N1UO/_EXWT_Y>!P@:1(@!1^*$*0/E"`$#YA?__%Y3"
M!I$!.(!2@()1^'#T_Y<!!``1/P0`<02(47K@``!4@0IQJ>,#`"H```"0`(0[
MD2$`0/G"\_^7\U-!J?5;0JGW8T.I^6M$J?MS1:G]>\:HP`-?UOU[OJG]`P"1
M\U,!J?,#`*KY^_^7\/O_E_0#`*J@_/^7'P``<60:0/J@`0!48`)`.6`!`#0!
M``"0X`,4JB$,-Y'V\_^7GP(`ZZ$``%3@`Q.J\U-!J?U[PJB&^O\7\U-!J?U[
MPJC``U_6_7N_J?T#`)']>\&HP`-?UG!E<FQX<VDN8P!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(```+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#4`
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`M90`M+0!54T52`%5315).04U%`%1%35!$25(`5$U0`"]T;7``
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?
M<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN
M+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@
M)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S
M=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB
M:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE
M.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I[
M"B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(
M+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S
M970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N
M;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B
M7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]
M("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#([
M"GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T
M.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS
M965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM
M>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?
M.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I
M;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE
M;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L
M("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB
M:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I
M92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")0
M2UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T
M85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H
M0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO
M*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*
M;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I
M('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL
M92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN
M("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F
M:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E
M;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@
M)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@
M1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E
M*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y0
M05(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET
M.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R
M;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@
M9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ
M."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R
M(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H
M.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%`A````````Z"````````````````````$``````````0`````````!
M`````````/4"````````#P````````"&!`````````P`````````&!H`````
M```-`````````%!,````````&0````````!HFP$``````!L`````````"```
M```````:`````````'";`0``````'``````````(`````````/7^_V\`````
MZ`$````````%`````````+@,````````!@````````#(`@````````H`````
M````I`0````````+`````````!@`````````%0````````````````````,`
M````````8)T!```````"`````````-`%````````%``````````'````````
M`!<`````````2!0````````'`````````&`1````````"`````````#H`@``
M``````D`````````&``````````8````````````````````^___;P`````!
M```(`````/G__V\`````$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#`:````````
M,!H````````P&@```````#`:````````,!H````````P&@```````#`:````
M````,!H````````P&@```````#`:````````,!H````````P&@```````#`:
M````````,!H````````P&@```````#`:````````,!H````````P&@``````
M`#`:````````,!H````````P&@```````#`:````````,!H````````P&@``
M`````#`:````````,!H````````P&@```````#`:````````,!H````````P
M&@```````#`:````````,!H````````P&@```````#`:````````,!H`````
M```P&@```````#`:````````,!H````````P&@```````#`:````````,!H`
M```````P&@```````#`:````````,!H````````P&@```````#`:````````
M,!H````````P&@```````#`:````````,!H````````P&@```````#`:````
M````,!H````````P&@```````#`:````````,!H````````P&@```````#`:
M````````,!H````````P&@```````#`:````````,!H```````"`FP$`````
M`#`>`````````````````````````````%!,````````````````````````
M````````````````&!H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P````!"3P```````(U,````````````
M``````!N30```````&=-````````-D\```````"$30```````#Y/````````
M```````````H3P```````"U/``````````````````!'3P```````$=#0SH@
M*$%L<&EN92`V+C0N,"D@-BXT+C```"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M
M;65N=```````````````````````````````````````````````````````
M```````````````````````````````````+`````0````(`````````R`$`
M``````#(`0```````!H````````````````````!````````````````````
M$P```/;__V\"`````````.@!````````Z`$```````#<``````````,`````
M````"````````````````````!T````+`````@````````#(`@```````,@"
M````````\`D````````$`````P````@`````````&``````````E`````P``
M``(`````````N`P```````"X#````````*0$```````````````````!````
M````````````````+0````0````"`````````&`1````````8!$```````#H
M`@````````,`````````"``````````8`````````#<````$````0@``````
M``!(%````````$@4````````T`4````````#````$0````@`````````&```
M``````!!`````0````8`````````&!H````````8&@```````!``````````
M```````````$````````````````````/`````$````&`````````#`:````
M````,!H`````````!```````````````````$``````````0`````````$<`
M```!````!@`````````P'@```````#`>````````("X`````````````````
M``0```````````````````!-`````0````8`````````4$P```````!03```
M`````!`````````````````````$````````````````````4P````$````"
M`````````&!,````````8$P````````;/P``````````````````"```````
M`````````````%L````!`````@````````!\BP```````'R+````````!```
M``````````````````0```````````````````!E````#@````,`````````
M:)L!``````!HFP````````@````````````````````(``````````@`````
M````<0````\````#`````````'";`0``````<)L````````(````````````
M````````"``````````(`````````'T````!`````P````````!XFP$`````
M`'B;````````"`````````````````````@```````````````````""````
M!@````,`````````@)L!``````"`FP```````.`!````````!``````````(
M`````````!``````````BP````$````#`````````&"=`0``````8)T`````
M``"@`@``````````````````"``````````(`````````)`````!`````P``
M````````H`$```````"@````````>`````````````````````@`````````
M``````````"6````"`````,`````````>*`!``````!XH````````&`0````
M```````````````(````````````````````FP````$````P````````````
M````````>*`````````:`````````````````````0`````````!````````
M``$````#`````````````````````````)*@````````I```````````````
4``````$`````````````````````
